/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- *//* 
 * Copyright (C) 1998-2000 Free Software Foundation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors: Eskil Heyn Olsen
 *          Manish Vachharajani
 *          Dave Camp
 *
 */

#ifndef _GPILOT_STRUCTURES_H_
#define _GPILOT_STRUCTURES_H_
#include <glib.h>
#include "gpilot-userinfo.h"

typedef struct GPilotContext {
	gboolean paused;
	GList *devices;
	GList *pilots;
	GPilotUser *user; /* Null in master global gpilotd */
	guint32 sync_PC_Id; /* Different for every gpilotd instance */
	gint progress_stepping;

#ifdef WITH_USB_VISOR
	/* For checking for visor devices */
	int visor_fd;
	GIOChannel *visor_io;
	guint visor_in_handle;
	guint visor_err_handle;
#endif
} GPilotContext;

GPilotContext *gpilot_context_new (void);
void gpilot_context_init_user (GPilotContext *context);
void gpilot_context_free (GPilotContext *context);

typedef enum GPilotDeviceType {
	PILOT_DEVICE_SERIAL,
	PILOT_DEVICE_USB_VISOR
} GPilotDeviceType;

typedef struct GPilotDevice {
	gchar *name;
	gchar *port;
	guint speed;
	/* These are used at runtime, to associate 
	   an opened file with the device */
	int fd;
	GIOChannel *io;    /* the g_io_channel is used for the polling */
	guint in_handle;   /* these two handles are used to be able to */
	guint err_handle;  /* pause the daemon's polling by g_source_remove */

	GPilotDeviceType type;
	gboolean device_exists : 1;  /* whether the usb cradle is active */
} GPilotDevice;

GPilotDevice *gpilot_device_new (void);
gint gpilot_device_init (GPilotDevice *device, gint i);
void gpilot_device_free (GPilotDevice *device);

#define GPILOT_DEVICE(s) ((GPilotDevice*)(s))
#endif /* _GPILOT_USERINFO_H_ */
